@@ -1,8 +1,8 @@
 from __future__ import annotations
 
-from typing import Optional
 from dataclasses import dataclass
 from enum import Enum
+from typing import Optional
 
 from .containers import (
     CleanRecord,
@@ -13,24 +13,10 @@ from .containers import (
     SmartWashParams,
     Status,
     WashTowelMode,
+    MultiMapsList,
 )
 
 
-class RoborockDevicePropField(str, Enum):
-    STATUS = "status"
-    DND_TIMER = "dnd_timer"
-    CLEAN_SUMMARY = "clean_summary"
-    CONSUMABLE = "consumable"
-    LAST_CLEAN_RECORD = "last_clean_record"
-    DOCK_SUMMARY = "dock_summary"
-
-
-class RoborockDockSummaryField(str, Enum):
-    DUST_COLLECTION_MODE = "dust_collection_mode"
-    WASHING_MODE_TYPE = "washing_mode_type"
-    MOP_WASH = "mop_wash"
-
-
 class RoborockCommand(str, Enum):
     GET_PROP = "get_prop"
     GET_MAP_V1 = "get_map_v1"
@@ -106,7 +92,6 @@ class RoborockCommand(str, Enum):
     SET_LED_STATUS = "set_led_status"
     GET_CAMERA_STATUS = "get_camera_status"
     CLOSE_DND_TIMER = "close_dnd_timer"
-    GET_MULTI_MAP = "get_multi_map"
     SET_COLLISION_AVOID_STATUS = "set_collision_avoid_status"
     SET_IDENTIFY_GROUND_MATERIAL_STATUS = "set_identify_ground_material_status"
     GET_IDENTIFY_GROUND_MATERIAL_STATUS = "get_identify_ground_material_status"
@@ -135,7 +120,7 @@ CommandInfoMap: dict[RoborockCommand, CommandInfo] = {
     RoborockCommand.GET_STATUS: CommandInfo(prefix=b"\x00\x00\x00\x77"),
     RoborockCommand.SET_CUSTOM_MODE: CommandInfo(prefix=b"\x00\x00\x00w"),
     RoborockCommand.GET_CHILD_LOCK_STATUS: CommandInfo(prefix=b"\x00\x00\x00\x87"),
-    RoborockCommand.GET_MULTI_MAPS_LIST: CommandInfo(prefix=b"\x00\x00\x00\x87"),
+    RoborockCommand.GET_MULTI_MAPS_LIST: CommandInfo(prefix=b"\x00\x00\x00\xd7"),
     RoborockCommand.GET_IDENTIFY_FURNITURE_STATUS: CommandInfo(prefix=b"\x00\x00\x00\x87"),
     RoborockCommand.SET_WATER_BOX_CUSTOM_MODE: CommandInfo(prefix=b"\x00\x00\x00\x87"),
     RoborockCommand.GET_CLEAN_SEQUENCE: CommandInfo(prefix=b"\x00\x00\x00\x87"),
@@ -168,16 +153,15 @@ CommandInfoMap: dict[RoborockCommand, CommandInfo] = {
     RoborockCommand.GET_CARPET_MODE: CommandInfo(prefix=b"\x00\x00\x00w"),
     RoborockCommand.GET_TIMEZONE: CommandInfo(prefix=b"\x00\x00\x00w"),
     RoborockCommand.SET_CARPET_MODE: CommandInfo(prefix=b"\x00\x00\x00\xd7"),
-    RoborockCommand.GET_MULTI_MAP: CommandInfo(prefix=b"\x00\x00\x00\xd7"),
-    RoborockCommand.SET_COLLISION_AVOID_STATUS: CommandInfo(prefix=b"\x00\x00\x97"),
-    RoborockCommand.SET_CARPET_CLEAN_MODE: CommandInfo(prefix=b"\x00\x00\x97"),
-    RoborockCommand.SET_IDENTIFY_GROUND_MATERIAL_STATUS: CommandInfo(prefix=b"\x00\x00\x97"),
-    RoborockCommand.GET_IDENTIFY_GROUND_MATERIAL_STATUS: CommandInfo(prefix=b"\x00\x00\x97"),
-    RoborockCommand.SET_VALLEY_ELECTRICITY_TIMER: CommandInfo(prefix=b"\x00\x00\x97"),
-    RoborockCommand.SWITCH_WATER_MARK: CommandInfo(prefix=b"\x00\x00\x97"),
-    RoborockCommand.SET_IDENTIFY_FURNITURE_STATUS: CommandInfo(prefix=b"\x00\x00\x97"),
-    RoborockCommand.SET_CHILD_LOCK_STATUS: CommandInfo(prefix=b"\x00\x00\x97"),
-    RoborockCommand.GET_CLEAN_RECORD_MAP: CommandInfo(prefix=b"\x00\x00\xe7"),
+    RoborockCommand.SET_COLLISION_AVOID_STATUS: CommandInfo(prefix=b"\x00\x00\x00\x97"),
+    RoborockCommand.SET_CARPET_CLEAN_MODE: CommandInfo(prefix=b"\x00\x00\x00\x97"),
+    RoborockCommand.SET_IDENTIFY_GROUND_MATERIAL_STATUS: CommandInfo(prefix=b"\x00\x00\x00\x97"),
+    RoborockCommand.GET_IDENTIFY_GROUND_MATERIAL_STATUS: CommandInfo(prefix=b"\x00\x00\x00\x97"),
+    RoborockCommand.SET_VALLEY_ELECTRICITY_TIMER: CommandInfo(prefix=b"\x00\x00\x00\x97"),
+    RoborockCommand.SWITCH_WATER_MARK: CommandInfo(prefix=b"\x00\x00\x00\x97"),
+    RoborockCommand.SET_IDENTIFY_FURNITURE_STATUS: CommandInfo(prefix=b"\x00\x00\x00\x97"),
+    RoborockCommand.SET_CHILD_LOCK_STATUS: CommandInfo(prefix=b"\x00\x00\x00\x97"),
+    RoborockCommand.GET_CLEAN_RECORD_MAP: CommandInfo(prefix=b"\x00\x00\x00\xe7"),
     RoborockCommand.APP_START: CommandInfo(prefix=b"\x00\x00\x00w"),
     RoborockCommand.APP_STOP: CommandInfo(prefix=b"\x00\x00\x00w"),
     RoborockCommand.APP_CHARGE: CommandInfo(prefix=b"\x00\x00\x00w"),
@@ -191,16 +175,16 @@ CommandInfoMap: dict[RoborockCommand, CommandInfo] = {
     RoborockCommand.APP_RC_END: CommandInfo(prefix=b"\x00\x00\x00w"),
     RoborockCommand.APP_RC_MOVE: CommandInfo(prefix=b"\x00\x00\x00w"),
     RoborockCommand.APP_GOTO_TARGET: CommandInfo(prefix=b"\x00\x00\x00\x87"),
-    RoborockCommand.APP_SEGMENT_CLEAN: CommandInfo(prefix=b"\x00\x00\x00\xc7"),
-    RoborockCommand.APP_ZONED_CLEAN: CommandInfo(prefix=b"\x00\x00\x00w"),
+    RoborockCommand.APP_SEGMENT_CLEAN: CommandInfo(prefix=b"\x00\x00\x00\x87"),
+    RoborockCommand.APP_ZONED_CLEAN: CommandInfo(prefix=b"\x00\x00\x00\x97"),
     RoborockCommand.APP_START_WASH: CommandInfo(prefix=b"\x00\x00\x00w"),
     RoborockCommand.APP_STOP_WASH: CommandInfo(prefix=b"\x00\x00\x00w"),
-    RoborockCommand.SET_FDS_ENDPOINT: CommandInfo(prefix=b"\x00\x00\x97"),
+    RoborockCommand.SET_FDS_ENDPOINT: CommandInfo(prefix=b"\x00\x00\x00\x97"),
     RoborockCommand.ENABLE_LOG_UPLOAD: CommandInfo(prefix=b"\x00\x00\x87"),
     RoborockCommand.GET_SOUND_VOLUME: CommandInfo(prefix=b"\x00\x00\x00w"),
     RoborockCommand.TEST_SOUND_VOLUME: CommandInfo(prefix=b"\x00\x00\x00w"),
     RoborockCommand.UPD_SERVER_TIMER: CommandInfo(prefix=b"\x00\x00\x00\x97"),
-    RoborockCommand.SET_APP_TIMEZONE: CommandInfo(prefix=b"\x00\x00\x97"),
+    RoborockCommand.SET_APP_TIMEZONE: CommandInfo(prefix=b"\x00\x00\x00\x97"),
     RoborockCommand.CHANGE_SOUND_VOLUME: CommandInfo(prefix=b"\x00\x00\x00\x87"),
     RoborockCommand.GET_SOUND_PROGRESS: CommandInfo(prefix=b"\x00\x00\x00w"),
     RoborockCommand.SET_SERVER_TIMER: CommandInfo(prefix=b"\x00\x00\x00\xc7"),
@@ -225,31 +209,18 @@ CommandInfoMap: dict[RoborockCommand, CommandInfo] = {
 
 
 @dataclass
-class RoborockDockSummary:
+class DockSummary:
     dust_collection_mode: Optional[DustCollectionMode] = None
     wash_towel_mode: Optional[WashTowelMode] = None
     smart_wash_params: Optional[SmartWashParams] = None
 
 
 @dataclass
-class RoborockDeviceProp:
+class DeviceProp:
     status: Optional[Status] = None
     dnd_timer: Optional[DNDTimer] = None
     clean_summary: Optional[CleanSummary] = None
     consumable: Optional[Consumable] = None
     last_clean_record: Optional[CleanRecord] = None
-    dock_summary: Optional[RoborockDockSummary] = None
-
-    def update(self, device_prop: "RoborockDeviceProp"):
-        if device_prop.status:
-            self.status = device_prop.status
-        if device_prop.dnd_timer:
-            self.dnd_timer = device_prop.dnd_timer
-        if device_prop.clean_summary:
-            self.clean_summary = device_prop.clean_summary
-        if device_prop.consumable:
-            self.consumable = device_prop.consumable
-        if device_prop.last_clean_record:
-            self.last_clean_record = device_prop.last_clean_record
-        if device_prop.dock_summary:
-            self.dock_summary = device_prop.dock_summary
+    dock_summary: Optional[DockSummary] = None
+    multi_maps_list: Optional[MultiMapsList] = None
